
About ``tspop``
===============

``tspop`` lets you extract information about population-based ancestry
from tree sequences simulated with ``msprime``.

Quickstart
==========

.. note::
   Do later.

Installation
------------

.. note::
   Do later.

Basic usage
-----------

.. note::
   Do later.

Developing with ``tspop``
=========================

To install ``tspop`` as well as the packages needed to develop and run
tests, run this in the ``virtualenv``:

```bash
$ pip install -e .[dev]	
```